@@ -31,32 +31,6 @@ class MockApplication(Application):
         pass
 
 
-class TestApplicationBase(object):
-
-    def setup_method(self, method):
-        self.app = MockApplication()
-
-    def test_suggest_mergers(self):
-        x = Data(x=[1, 2, 3])
-        y = Data(y=[1, 2, 3, 4])
-        z = Data(z=[1, 2, 3])
-
-        Application._choose_merge = MagicMock()
-        Application._choose_merge.return_value = ([x], 'mydata')
-        self.app.data_collection.merge = MagicMock()
-
-        self.app.data_collection.append(x)
-        self.app.data_collection.append(y)
-
-        self.app.add_datasets(self.app.data_collection, z)
-
-        args = self.app._choose_merge.call_args[0]
-        assert args[0] == z
-        assert args[1] == [x]
-
-        assert self.app.data_collection.merge.call_count == 1
-
-
 def test_session(tmpdir):
     session_file = tmpdir.join('test.glu').strpath
     app = MockApplication()
@@ -104,7 +78,7 @@ def test_nested_data():
 
     app = Application()
 
-    app.add_datasets(app.data_collection, datasets)
+    app.add_datasets(datasets)
 
     assert x in app.data_collection
     assert y in app.data_collection
