@@ -102,7 +102,7 @@ def parse_data(data, label):
 
 
 def parse_links(dc, links):
-    from glue.core.link_helpers import multi_link
+    from glue.core.link_helpers import MultiLink
     from glue.core import ComponentLink
 
     data = dict((d.label, d) for d in dc)
@@ -135,7 +135,7 @@ def parse_links(dc, links):
             result.append(ComponentLink(f, t, u))
         else:
             t = [find_cid(item) for item in t]
-            result += multi_link(f, t, u, u2)
+            result += MultiLink(f, t, u, u2)
 
     return result
 
@@ -182,6 +182,7 @@ def qglue(**kwargs):
     """
     from glue.core import DataCollection
     from glue.app.qt import GlueApplication
+    from glue.dialogs.autolinker.qt import run_autolinker
 
     links = kwargs.pop('links', None)
 
@@ -194,6 +195,7 @@ def qglue(**kwargs):
 
     with restore_io():
         ga = GlueApplication(dc)
+        run_autolinker(dc)
         ga.start()
 
     return ga
